<?php
namespace FM\Factory;

use Doctrine\ORM\EntityManager;

class GraficoFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        
        $this->connection = $entityManager->getConnection();
    }
    
    public function getUnidade() {
        
        $sql = "SELECT NMLOCALCLIENTE, NRLOCALCLIENTE
                  FROM FCM_LOCALCLI
                 WHERE NRLOCALCLIENTEPAI IS NULL";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }

    public function getFonteDados() {
        
        $sql = "SELECT NRFONTEDADOSGRAFREL, 
                       NMFONTEDADOSGRAFREL
                FROM FCM_FONTEDADOSGRAFREL";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }

    public function getMetricas($parametro) {
        
        $sql = "SELECT NRDADOSGRAFREL,
                       NMDADOSGRAFREL
                FROM FCM_DADOSGRAFREL ".$parametro;
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function getAtividades() {
        
        $sql = "SELECT NRATIVIDADE, NMATIVIDADE
                  FROM FCM_ATIVIDADE
                  ORDER BY NMATIVIDADE";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function consultaDinamica($parametro) {
      $dsCustomizado = $parametro['consulta'];
      $sql = "$dsCustomizado";
       
      $std = $this->connection->prepare($sql);       
      $std->execute();
      return $std->fetchAll();
    }
    
    public function getDadosGraficosGerados($parametro) {
        
      $sql = "SELECT NRGRAFICOS, 
                     NMGRAFICOS, 
                     IDTPGRAFICO,
                     TXCONSULTAGRAFICO,
                    (CASE IDTPGRAFICO
                    WHEN '1' THEN 'Linha' 
                    WHEN '2' THEN 'Barra' 
                    WHEN '3' THEN 'Area' 
                    WHEN '4' THEN 'Pizza' 
                    WHEN '5' THEN 'Radial'
                    END ) AS TIPO
              FROM FCM_GRAFICOS ".$parametro."
              ORDER BY NRGRAFICOS ASC";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function deletaGraficoGerado($parametro) {
      $sql = "DELETE FROM FCM_GRAFICOS
              WHERE NRGRAFICOS IN ($parametro)";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
    }
    
    public function deletaUsuariosPermitidos($parametro) {

      $sql = "DELETE FROM FCM_PERMACESSGRAFICOS
              WHERE NRGRAFICOS IN($parametro)";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
    }
    
    public function deletaConfGraficos($parametro) {
      $sql = "DELETE FROM FCM_CONFGRAFICOS
              WHERE NRGRAFICOS IN($parametro)";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
    }
    
    public function insertGrafico($parametro) {
      $sql = "INSERT INTO FCM_GRAFICOS (NRGRAFICOS, NMGRAFICOS, NRFONTEDADOSGRAFREL,IDTPGRAFICO,
                                        IDPERIODO, DTINIGRAFICO,DTFIMGRAFICO,IDGRAFICOPUB,TXCONSULTAGRAFICO,NRORG,
                                        IDATIVO,DTINCLUSAO,CDOPERINCLUSAO,NRORGINCLUSAO)
                          VALUES (:NRGRAFICOS, :NMGRAFICOS, :NRFONTEDADOSGRAFREL, :IDTPGRAFICO,
                          :IDPERIODO,TO_DATE(:DTINIGRAFICO,'DD/MM/YYYY'),TO_DATE(:DTFIMGRAFICO,'DD/MM/YYYY'),:IDGRAFICOPUB,:TXCONSULTAGRAFICO,:NRORG,
                          :IDATIVO, SYSDATE,:CDOPERINCLUSAO,:NRORGINCLUSAO)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
    }
    
    public function insertConfGrafico($parametro) {
      $sql = "INSERT INTO FCM_CONFGRAFICOS (NRCONFGRAFICO,NRGRAFICOS,IDDIMENSAODADO,NRDADOSGRAFREL,NRORG,IDATIVO,DTINCLUSAO,CDOPERINCLUSAO,NRORGINCLUSAO)
                          VALUES (:NRCONFGRAFICO,:NRGRAFICOS,:IDDIMENSAODADO,:NRDADOSGRAFREL,:NRORG,:IDATIVO,SYSDATE,:CDOPERINCLUSAO,:NRORGINCLUSAO)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
    }
    
    public function insertPemissao($parametro) {
        
      $sql = "INSERT INTO FCM_PERMACESSGRAFICOS (NRPERMACESSGRAFICO,NRGRAFICOS,NRFUNCIONARIO,NRORG,IDATIVO,DTINCLUSAO,CDOPERINCLUSAO,NRORGINCLUSAO)
                          VALUES (:NRPERMACESSGRAFICO, :NRGRAFICOS, :NRFUNCIONARIO, :NRORG, :IDATIVO, SYSDATE,:CDOPERINCLUSAO,:NRORGINCLUSAO)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametro);
    }
    
    public function buscaDadosGrafRel($parametro) {
      $sql = "SELECT NMTABELADADO, NMCAMPODADO, NMCAMPONOMEDADO, NMTABELANOMEDADO, DSSQLCUSTOMIZADO, NMTABELADATAFILTRO, NMCAMPODATAFILTRO
              FROM FCM_DADOSGRAFREL
              WHERE NRDADOSGRAFREL IN($parametro)";
       
      $std = $this->connection->prepare($sql);       
      $std->execute();
      return $std->fetchAll();
    }
    
    public function getDadosGraficos($parametro){
      $sql = "SELECT NMGRAFICOS, 
                    NRFONTEDADOSGRAFREL, 
                    IDTPGRAFICO,
                    IDPERIODO,
                    TO_CHAR(DTINIGRAFICO,'DD/MM/YYYY') AS DATAINICIO,
                    TO_CHAR(DTFIMGRAFICO,'DD/MM/YYYY') AS DATAFINAL,
                    IDGRAFICOPUB
              FROM FCM_GRAFICOS
              WHERE NRGRAFICOS = {$parametro}";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function getDadosConfGraficos($parametro){
      $sql = "SELECT IDDIMENSAODADO, NRDADOSGRAFREL 
              FROM FCM_CONFGRAFICOS 
              WHERE NRGRAFICOS = {$parametro}";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function getDadosUsuariosPermitidos($parametro){
      $sql = "SELECT NRFUNCIONARIO 
              FROM FCM_PERMACESSGRAFICOS
              WHERE NRGRAFICOS = {$parametro}";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }

    public function buscaDadosGrafico($parametro) {
        
        $sql = "SELECT NMGRAFICOS,
                    NRFONTEDADOSGRAFREL,
                    IDTPGRAFICO,
                    IDPERIODO,
                    TO_CHAR(DTINIGRAFICO,'DD/MM/YYYY') AS DATAINICIO,
                    TO_CHAR(DTFIMGRAFICO,'DD/MM/YYYY') AS DATAFINAL,
                    IDGRAFICOPUB,
                    TXCONSULTAGRAFICO,
                    NRORG,
                    IDATIVO,
                    CDOPERINCLUSAO,
                    NRORGINCLUSAO
                FROM FCM_GRAFICOS
                WHERE NRGRAFICOS = ".$parametro;
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function buscaDadosConfGrafico($parametro) {
        
        $sql = "SELECT IDDIMENSAODADO,
                        NRDADOSGRAFREL,
                        NRORG,
                        IDATIVO,
                        CDOPERINCLUSAO,
                        NRORGINCLUSAO
                FROM FCM_CONFGRAFICOS
                WHERE NRGRAFICOS = ".$parametro;
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function buscaDadosPermGrafico($parametro) {
        
        $sql = "SELECT NRFUNCIONARIO,
                        NRORG,
                        IDATIVO,
                        CDOPERINCLUSAO,
                        NRORGINCLUSAO
                FROM  FCM_PERMACESSGRAFICOS
                WHERE NRGRAFICOS = ".$parametro;
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function updateGraficos($parametroUpdateGrafico) {
        $sql = "UPDATE  FCM_GRAFICOS
                SET NMGRAFICOS = :NMGRAFICOS,
                 NRFONTEDADOSGRAFREL = :NRFONTEDADOSGRAFREL,
                 IDTPGRAFICO = :IDTPGRAFICO,
                 IDPERIODO = :IDPERIODO,
                 DTINIGRAFICO = TO_DATE(:DTINIGRAFICO,'DD/MM/YYYY'),
                 DTFIMGRAFICO = TO_DATE(:DTFIMGRAFICO,'DD/MM/YYYY'),
                 IDGRAFICOPUB = :IDGRAFICOPUB,
                 TXCONSULTAGRAFICO = :TXCONSULTAGRAFICO
                WHERE  NRGRAFICOS = :NRGRAFICOS";
                
        $std =  $this->connection->prepare($sql);
        $std->execute($parametroUpdateGrafico);
    }
    
}